@@ -163,7 +163,7 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 	updateSettingsFromConfig();
 
 	setTextFormat( Qt::RichText );
-	
+
 	if ( m_bLineWrapping )
 		setWordWrap(WidgetWidth);
 	else
@@ -176,13 +176,19 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 	mimeSourceFactory()->setImage("warning", QImage((const char**)warning_xpm));
 	mimeSourceFactory()->setImage("message", QImage((const char**)message_xpm));
 
+        dirstack.setAutoDelete(true);
+
 	childproc = new KProcess(this);
 	procLineMaker = new ProcessLineMaker( childproc );
 
-	connect( procLineMaker, SIGNAL(receivedStdoutLine(const QString&)),
-	         this, SLOT(insertStdoutLine(const QString&) ));
-	connect( procLineMaker, SIGNAL(receivedStderrLine(const QString&)),
-	         this, SLOT(insertStderrLine(const QString&) ));
+	connect( procLineMaker, SIGNAL(receivedStdoutLine(const QCString&)),
+	         this, SLOT(insertStdoutLine(const QCString&) ));
+	connect( procLineMaker, SIGNAL(receivedStderrLine(const QCString&)),
+                 this, SLOT(insertStderrLine(const QCString&) ));
+        connect( procLineMaker, SIGNAL(receivedPartialStdoutLine(const QCString&)),
+                 this, SLOT(storePartialStdoutLine(const QCString&) ));
+        connect( procLineMaker, SIGNAL(receivedPartialStderrLine(const QCString&)),
+                 this, SLOT(storePartialStderrLine(const QCString&) ));
 
 	connect( childproc, SIGNAL(processExited(KProcess*)),
 	         this, SLOT(slotProcessExited(KProcess*) )) ;
@@ -207,8 +213,9 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 	connect( horizontalScrollBar(), SIGNAL(sliderReleased()),
 	         this, SLOT(horizScrollingOff()) );
 
-	connect( m_part->partController(), SIGNAL(loadedFile(const KURL&)),
-	         this, SLOT(slotDocumentOpened(const KURL&)) );
+// this slot doesn't exist anymore
+// 	connect( m_part->partController(), SIGNAL(loadedFile(const KURL&)),
+// 	         this, SLOT(slotDocumentOpened(const KURL&)) );
 }
 
 MakeWidget::~MakeWidget()
@@ -314,8 +321,8 @@ void MakeWidget::copy()
 	for(int i = parafrom; i<=parato; i++)
 	   selection += text(i) + "\n";
 
-   	   
-	if(m_compilerOutputLevel == eShort || 
+
+	if(m_compilerOutputLevel == eShort ||
 	   m_compilerOutputLevel == eVeryShort )
 	{
 	   QRegExp regexp("<.*>");
@@ -327,14 +334,14 @@ void MakeWidget::copy()
 	  selection.remove(0, indexfrom);
 	  int removeend = text(parato).length() - indexto;
 
-	  selection.remove((selection.length()-1) -  removeend, removeend);	   
-	}		
-	   
+	  selection.remove((selection.length()-1) -  removeend, removeend);
+	}
+
 	selection.replace("&lt;","<");
 	selection.replace("&gt;",">");
 	selection.replace("&quot;","\"");
-	selection.replace("&amp;","&");	
-	   
+	selection.replace("&amp;","&");
+
 	kapp->clipboard()->setText(selection, QClipboard::Clipboard);
 }
 
@@ -442,6 +449,17 @@ void MakeWidget::specialCheck( const QString& file, QString& fName ) const
             kdDebug(9004) << "MakeWidget::specialCheck thinks that url is: " << url.url()
                 << " origin: " << file << endl;
             fName = url.url();
+            return;
+        }
+    }
+    // Ok the "worst case", lets see if we can find a file in the project that has the same name
+    // obviously this will pick always the wrong file when you've got the same filename multiple times.
+    QStringList files = m_part->project()->allFiles();
+    for( QStringList::iterator it = files.begin() ; it != files.end(); ++it)
+    {
+        if( (*it).contains( file ) )
+        {
+            fName = URLUtil::canonicalPath( m_part->project()->projectDirectory() + "/" + *it );
         }
     }
 }
@@ -510,23 +528,44 @@ void MakeWidget::searchItem(int parag)
 	}
 }
 
-void MakeWidget::insertStdoutLine( const QString& line )
+void MakeWidget::insertStdoutLine( const QCString& line )
 {
-	if ( !appendToLastLine( line ) )
-		m_directoryStatusFilter.processLine( line );
+    QString sline;
+    bool forceCLocale = KConfigGroup( kapp->config(), "MakeOutputWidget" ).readBoolEntry( "ForceCLocale", true );
+    
+    if( forceCLocale )
+        sline = QString::fromAscii( stdoutbuf+line );
+    else
+        sline = QString::fromLocal8Bit( stdoutbuf+line );
+
+    if ( !appendToLastLine( sline ) )
+        m_directoryStatusFilter.processLine( sline );
+    stdoutbuf.truncate(0);
 }
 
-void MakeWidget::insertStderrLine( const QString& line )
+void MakeWidget::insertStderrLine( const QCString& line )
 {
-	if ( !appendToLastLine( line ) )
-        {
-            kdDebug() << "inserting stderr line: " << line << endl;
-		m_errorFilter.processLine( line );
-  }
+    QString sline;
+    bool forceCLocale = KConfigGroup( kapp->config(), "MakeOutputWidget" ).readBoolEntry( "ForceCLocale", true );
+    
+    if( forceCLocale ) {
+        sline = QString( stderrbuf+line );
+    }
+    else
+        sline = QString::fromLocal8Bit( stderrbuf+line );
+    
+    if ( !appendToLastLine( sline ) )
+        m_errorFilter.processLine( sline );
+    stderrbuf.truncate(0);
 }
 
 void MakeWidget::slotProcessExited(KProcess *)
 {
+	procLineMaker->flush();
+    if( !stderrbuf.isEmpty() )
+        insertStderrLine("");
+    if( !stdoutbuf.isEmpty() )
+        insertStdoutLine("");
 	if (childproc->normalExit())
 	{
 		if (childproc->exitStatus())
@@ -543,7 +582,7 @@ void MakeWidget::slotProcessExited(KProcess *)
 
 	MakeItem* item = new ExitStatusItem( childproc->normalExit(), childproc->exitStatus() );
 	insertItem( item );
-  displayPendingItem();
+        displayPendingItem();
 
 	m_part->mainWindow()->statusBar()->message( QString("%1: %2").arg(currentCommand).arg(item->m_text), 3000);
 	m_part->core()->running(m_part, false);
@@ -598,7 +637,7 @@ void MakeWidget::displayPendingItem()
   // We call displayPendingItem once in insertItem
   // and the appends are handled directly in
   // appendToLastLine
-  if (!m_items.empty() 
+  if (!m_items.empty()
       && m_items.last() == m_pendingItem) return;
 
   m_items.push_back(m_pendingItem);
@@ -793,4 +832,14 @@ bool MakeWidget::scanErrorBackward( int parag )
 	return false;
 }
 
+void MakeWidget::storePartialStderrLine(const QCString & line)
+{
+    stderrbuf += line;
+}
+
+void MakeWidget::storePartialStdoutLine(const QCString & line)
+{
+    stdoutbuf += line;
+}
+
 #include "makewidget.moc"
